pub struct UpdateUserApiKeyOptions {
pub name: Option<CompactString>,
pub allowed_ips: Option<Vec<IpNetwork>>,
pub user_permissions: Option<Vec<CompactString>>,
pub admin_permissions: Option<Vec<CompactString>>,
pub server_permissions: Option<Vec<CompactString>>,
pub expires: Option<Option<DateTime<Utc>>>,
}Fields
name: Option<CompactString>allowed_ips: Option<Vec<IpNetwork>>user_permissions: Option<Vec<CompactString>>admin_permissions: Option<Vec<CompactString>>server_permissions: Option<Vec<CompactString>>expires: Option<Option<DateTime<Utc>>>Trait Implementations
Sourceimpl ComposeSchema for UpdateUserApiKeyOptions
impl ComposeSchema for UpdateUserApiKeyOptions
Sourceimpl Default for UpdateUserApiKeyOptions
impl Default for UpdateUserApiKeyOptions
Sourcefn default() -> UpdateUserApiKeyOptions
fn default() -> UpdateUserApiKeyOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateUserApiKeyOptions
impl<'de> Deserialize<'de> for UpdateUserApiKeyOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for UpdateUserApiKeyOptions
impl Serialize for UpdateUserApiKeyOptions
Sourceimpl ToSchema for UpdateUserApiKeyOptions
impl ToSchema for UpdateUserApiKeyOptions
Sourceimpl Validate for UpdateUserApiKeyOptions
impl Validate for UpdateUserApiKeyOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for UpdateUserApiKeyOptions
impl RefUnwindSafe for UpdateUserApiKeyOptions
impl Send for UpdateUserApiKeyOptions
impl Sync for UpdateUserApiKeyOptions
impl Unpin for UpdateUserApiKeyOptions
impl UnwindSafe for UpdateUserApiKeyOptions